# This file has been generated


build_system = 'AppVeyor'
build_id = '33347639'
build_number = '666'
build_version = '1.0.666'
job_id = 'yv4m1noad28fv4j6'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/yv4m1noad28fv4j6'



# This file was automatically generated by sub\epyqlib\epyqlib\cli\generateversion.py
__version_build_time__ = '2020-06-05T19:45:40.533490'

__version__ = '2020.6.1'
__sha__ = '18c7876931cbcf8be454d5bb32620ef3ad21376e'
__revision__ = '18c7876931cbcf8be454d5bb32620ef3ad21376e'
